package com.baidu.maplite.harmonyos.demo.pages;


import com.baidu.mapapi.map.BaiduMap;
import com.baidu.mapapi.map.MapView;
import com.baidu.mapapi.map.Marker;
import com.baidu.mapapi.map.MarkerOptions;
import com.baidu.mapapi.model.LatLng;
import ohos.aafwk.content.Intent;
import ohos.agp.components.Button;
import ohos.agp.components.ComponentContainer;
import ohos.agp.window.dialog.ToastDialog;
import ohos.hiviewdfx.HiLog;

public class AddMarkerAbility extends CustomAbility {

    /**
     * mMapView
     */
    private MapView mMapView;

    /**
     * mMapView控制器
     */
    private BaiduMap mBaiduMap;

    private Marker marker;

    @Override
    public void onStart(Intent intent) {
        super.onStart(intent);
        setWindowBgToAdaptWebView();
        // 添加控件
        initPositionLayout();
        addMapView();
        addButtons();
        super.setUIContent(this.rootLayout);
    }

    @Override
    public void onActive() {
        super.onActive();
        mMapView.onResume();
    }

    @Override
    public void onForeground(Intent intent) {
        super.onForeground(intent);
        mMapView.onPause();
    }

    @Override
    protected void onStop() {
        super.onStop();
        mMapView.onDestroy();
    }

    private void addMapView() {
        // 创建mMapView
        mMapView = new MapView(getContext());
        mMapView.setPosition(0, 0);
        mMapView.setWidth(ComponentContainer.LayoutConfig.MATCH_PARENT);
        mMapView.setHeight(ComponentContainer.LayoutConfig.MATCH_PARENT);
        this.rootLayout.addComponent(mMapView);
        mBaiduMap = mMapView.getMap();
        // 地图点击回调
        mBaiduMap.setOnMapClickListener(this::mapClicked);
        // marker点击回调
        mBaiduMap.setOnMarkerClickListener(this::markerClicked);
        // marker拖拽回调
        mBaiduMap.setOnMarkerDragListener(new BaiduMap.OnMarkerDragListener() {
            @Override
            public void onMarkerDrag(Marker marker) {
                markerDraging(marker);
            }

            @Override
            public void onMarkerDragEnd(Marker marker) {
                markerDragEnd(marker);
            }

            @Override
            public void onMarkerDragStart(Marker marker) {
                markerDragStart(marker);
            }
        });
    }

    private void addButtons() {
        // 添加一个按钮
        Button button = createButton();
        button.setContentPosition(vp2px(0), vp2px(24));
        button.setText("addMarker");
        button.setTouchEventListener((component, touchEvent) -> true);
        // btn 点击事件
        button.setClickedListener(component -> addMarker());
        this.rootLayout.addComponent(button);

        // 添加一个按钮
        Button button2 = createButton();
        button2.setContentPosition(vp2px(0), vp2px(87));
        button2.setText("remove");
        button2.setTouchEventListener((component, touchEvent) -> true);
        // btn 点击事件
        button2.setClickedListener(component -> removeMarker());
        this.rootLayout.addComponent(button2);

//        // 添加一个按钮
//        Button button3 = createButton();
//        button3.setContentPosition(vp2px(0), vp2px(150));
//        button3.setText("switchMarkerDrag");
//        button3.setTouchEventListener((component, touchEvent) -> true);
//        // btn 点击事件
//        button3.setClickedListener(component -> switchMarkerDrag());
//        this.rootLayout.addComponent(button3);
//
//        // 添加一个按钮
//        Button button4 = createButton();
//        button4.setContentPosition(vp2px(0), vp2px(213));
//        button4.setText("switchMarkerClick");
//        button4.setTouchEventListener((component, touchEvent) -> true);
//        // btn 点击事件
//        button4.setClickedListener(component -> switchMarkerClick());
//        this.rootLayout.addComponent(button4);

        // 添加一个按钮
        Button button5 = createButton();
        button5.setContentPosition(vp2px(0), vp2px(276));
        button5.setText("showToast");
        button5.setTouchEventListener((component, touchEvent) -> true);
        // btn 点击事件
        button5.setClickedListener(component -> showToast());
        this.rootLayout.addComponent(button5);
    }

    // 添加marker
    private void addMarker() {
        if (marker == null) {
            HiLog.debug(TAG, "mapAddMarker");
            MarkerOptions markerOptions = new MarkerOptions().
                    position(new LatLng(39.915, 116.404)). // 设置Marker位置，不能包含 null
                    clickable(true). // 设置Marker是否可点击
                    draggable(true); // 设置 marker 是否允许拖拽，默认不可拖拽
            marker = (Marker) mBaiduMap.addOverlay(markerOptions);
        } else {
            ToastDialog toastDialog = new ToastDialog(this);
            toastDialog.setText("Marker 已存在")
                    .setDuration(5000)
                    .show();
        }
    }

    // 移除Marker
    private void removeMarker() {
        if (marker != null) {
            HiLog.debug(TAG, "mapRemoveMarker");
//        mBaiduMap.clear();
            marker.remove();
            marker = null;
        }

    }

    // 改变Marker拖拽状态
//    private void switchMarkerDrag() {
//        if (marker != null) {
//            if (marker.isDraggable()) {
//                marker.setDraggable(false);
//                ToastDialog toastDialog = new ToastDialog(this);
//                toastDialog.setText("Marker is " + marker.isDraggable())
//                        .setDuration(1000)
//                        .show();
//            } else {
//                marker.setDraggable(true);
//                ToastDialog toastDialog = new ToastDialog(this);
//                toastDialog.setText("Marker is " + marker.isDraggable())
//                        .setDuration(1000)
//                        .show();
//            }
//        } else {
//            HiLog.debug(TAG, "switchMarkerDrag");
//            ToastDialog toastDialog = new ToastDialog(this);
//            toastDialog.setText("Marker is null")
//                    .setDuration(1000)
//                    .show();
//        }
//    }
//
//    // 改变Marker点击状态
//    private void switchMarkerClick() {
//        if (marker != null) {
//            if (marker.isClickable()) {
//                marker.setClickable(false);
//                ToastDialog toastDialog = new ToastDialog(this);
//                toastDialog.setText("Marker is " + marker.isClickable())
//                        .setDuration(1000)
//                        .show();
//            } else {
//                marker.setClickable(true);
//                ToastDialog toastDialog = new ToastDialog(this);
//                toastDialog.setText("Marker is " + marker.isClickable())
//                        .setDuration(1000)
//                        .show();
//            }
//        } else {
//            HiLog.debug(TAG, "switchMarkerClick");
//            ToastDialog toastDialog = new ToastDialog(this);
//            toastDialog.setText("Marker is null")
//                    .setDuration(1000)
//                    .show();
//        }
//    }

    // 获取Marker信息
    private void showToast() {
        if (marker != null) {
            HiLog.debug(TAG, "showToast");
            ToastDialog toastDialog = new ToastDialog(this);
            toastDialog.setText("Maker可拖拽状态" + marker.isDraggable() + "\nMarker坐标\n" + marker.getPosition()
                    + "\n水平方向锚点比例\n" + marker.getAnchorX() + "\n垂直方向锚点比例\n:" + marker.getAnchorY()
                    + "\n旋转角度\n" + marker.getRotate() + "\nMarker ID\n" + marker.getId() + "\nMarker可点击状态"
                    + marker.isClickable())
                    .setDuration(1000)
                    .show();
        }
    }

    // 地图点击回调
    private void mapClicked(LatLng point) {
        new ToastDialog(getContext()).
                setText("onMapClick:" + point.toString()).
                show();
    }

    // marker点击事件回调
    private boolean markerClicked(Marker marker) {
        new ToastDialog(getContext()).
                setText("markerClicked:" + marker.getId()).
                show();
        return true;
    }

    // marker拖拽开始事件回调
    private void markerDragStart(Marker marker) {
        HiLog.debug(TAG, "markerDragStart:" + marker.getId());
    }

    // marker拖拽中事件回调
    private void markerDraging(Marker marker) {
        HiLog.debug(TAG, "markerDraging:" + marker.getId());
    }

    // marker拖拽结束事件回调
    private void markerDragEnd(Marker marker) {
        HiLog.debug(TAG, "markerDragEnd:" + marker.getId());
    }
}
