package com.baidu.maplite.harmonyos.demo.pages;


import com.baidu.mapapi.map.BaiduMap;
import com.baidu.mapapi.map.MapView;
import com.baidu.mapapi.map.Polyline;
import com.baidu.mapapi.map.PolylineOptions;
import com.baidu.mapapi.model.LatLng;
import ohos.aafwk.content.Intent;
import ohos.agp.components.Button;
import ohos.agp.components.ComponentContainer;
import ohos.agp.window.dialog.ToastDialog;
import ohos.hiviewdfx.HiLog;

import java.util.ArrayList;
import java.util.List;

public class AddPolylineAbility extends CustomAbility {
    /**
     * mapView
     */
    private MapView mMapView;

    /**
     * mapView控制器
     */
    private BaiduMap mBaiduMap;

    private Polyline polyline;

    @Override
    public void onStart(Intent intent) {
        super.onStart(intent);
        setWindowBgToAdaptWebView();
        // 添加控件
        initPositionLayout();
        addMapView();
        addButtons();
        super.setUIContent(this.rootLayout);
    }

    @Override
    public void onActive() {
        super.onActive();
        mMapView.onResume();
    }

    @Override
    public void onForeground(Intent intent) {
        super.onForeground(intent);
        mMapView.onPause();
    }

    @Override
    protected void onStop() {
        super.onStop();
        mMapView.onDestroy();
    }
    private void addMapView() {
        // 创建mMapView
        mMapView = new MapView(getContext());
        mMapView.setPosition(0, 0);
        mMapView.setWidth(ComponentContainer.LayoutConfig.MATCH_PARENT);
        mMapView.setHeight(ComponentContainer.LayoutConfig.MATCH_PARENT);
        rootLayout.addComponent(mMapView);
        mBaiduMap = mMapView.getMap();
        // polyline点击事件回调
        mBaiduMap.setOnPolylineClickListener(this::polylineClicked);
    }

    private void addButtons() {
        // 添加一个按钮
        Button button = createButton();
        button.setContentPosition(0, vp2px(24));
        button.setText("addPolyline");
        button.setTouchEventListener((component, touchEvent) -> true);
        // btn 点击事件
        button.setClickedListener(component -> addPolyline());
        this.rootLayout.addComponent(button);

        // 添加一个按钮
        Button button2 = createButton();
        button2.setContentPosition(0, vp2px(87));
        button2.setText("remove");
        button2.setTouchEventListener((component, touchEvent) -> true);
        // btn 点击事件
        button2.setClickedListener(component -> removePolyline());
        this.rootLayout.addComponent(button2);
    }


    // 添加折线
    private void addPolyline() {
        if (polyline == null) {
            HiLog.debug(TAG, "mapAddPolyline");
            List<LatLng> points = new ArrayList<>();
            points.add(new LatLng(39.970475, 116.287561));
            points.add(new LatLng(39.910951, 116.39392));
            points.add(new LatLng(39.979985, 116.443363));
            points.add(new LatLng(39.916264, 116.520977));

            PolylineOptions polylineOptions = new PolylineOptions().
                    points(points). // 设置折线坐标点列表，不能包含 null
                    color(0xAA0000CD). //  折线颜色。注意颜色值得格式为：0xAARRGGBB，透明度值在前
                    width(10); // 设置折线线宽， 默认为 5，

            // 地图添加折线
            polyline = (Polyline) mBaiduMap.addOverlay(polylineOptions);
        } else {
            ToastDialog toastDialog = new ToastDialog(this);
            toastDialog.setText("Polyline 已存在")
                    .setDuration(5000)
                    .show();
        }
    }

    // 移除折线
    private void removePolyline() {
        if (polyline != null) {
            HiLog.debug(TAG, "mapRemovePolyline");
//        mBaiduMap.clear();
            polyline.remove();
            polyline = null;
        }

    }

    private boolean polylineClicked(Polyline polyline) {
        new ToastDialog(getContext()).
                setText("polylineClicked:" + polyline.getId()).
                show();
        return true;
    }
}
