package com.baidu.maplite.harmonyos.demo.pages;


import com.baidu.maplite.harmonyos.demo.ResourceTable;
import ohos.aafwk.ability.Ability;
import ohos.agp.colors.RgbColor;
import ohos.agp.components.*;
import ohos.agp.components.element.ShapeElement;
import ohos.hiviewdfx.HiLog;
import ohos.hiviewdfx.HiLogLabel;
import ohos.media.image.ImagePacker;
import ohos.media.image.PixelMap;
import ohos.media.image.common.PixelFormat;
import ohos.media.image.common.Size;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;


public class CustomAbility extends Ability {
    public static final HiLogLabel TAG = new HiLogLabel(HiLog.LOG_APP, 200, "BaiduMap");

    /**
     * 布局
     */
    public PositionLayout rootLayout;

    // 若mapView上方需要添加控件，则需要在setUIContent之前调用该方法
    public void setWindowBgToAdaptWebView() {
        final String backgroundFileName = "_bg.jpg";
        File file = new File(getContext().getFilesDir(), backgroundFileName);
        if (file.exists()) {
            getWindow().setBackground(file.getPath());
            return;
        }
        PixelMap pixelMap = createBgPixelMap();
        if (pixelMap == null) {
            return;
        }
        ImagePacker imagePacker = ImagePacker.create();
        try (OutputStream outputStream = new FileOutputStream(file)) {
            ImagePacker.PackingOptions options = new ImagePacker.PackingOptions();
            if (!imagePacker.initializePacking(outputStream, options)) {
                return;
            }
            if (!imagePacker.addImage(pixelMap)) {
                return;
            }
            if (imagePacker.finalizePacking() < 0) {
                return;
            }
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            imagePacker.release();
        }
        getWindow().setBackground(file.getPath());
    }

    private PixelMap createBgPixelMap() {
        final int length = 10;
        PixelMap.InitializationOptions initializationOptions = new PixelMap.InitializationOptions();
        initializationOptions.size = new Size(length, length);
        initializationOptions.pixelFormat = PixelFormat.ARGB_8888;
        initializationOptions.editable = true;
        int[] defaultColors = new int[length * length];
        return PixelMap.create(defaultColors, initializationOptions);
    }

    public void initPositionLayout() {
        this.rootLayout = new PositionLayout(this);
        this.rootLayout.setContentPosition(0, 0);
        this.rootLayout.setWidth(ComponentContainer.LayoutConfig.MATCH_PARENT);
        this.rootLayout.setHeight(ComponentContainer.LayoutConfig.MATCH_PARENT);
        // 背景色
        ShapeElement shapeElement = new ShapeElement();
        shapeElement.setShape(ShapeElement.ALPHA_MIN);
        shapeElement.setRgbColor(new RgbColor(255, 255, 255));
        this.rootLayout.setBackground(shapeElement);

    }

    public Button createButton() {
        Component component = LayoutScatter.getInstance(getContext())
                .parse(ResourceTable.Layout_button_layout, null, false);
        return (Button) component;
    }

    public int vp2px(float vp) {
        return AttrHelper.vp2px(vp, this);
    }

}
