package com.baidu.maplite.harmonyos.demo.pages;


import com.baidu.mapapi.map.BaiduMap;
import com.baidu.mapapi.map.MapStatus;
import com.baidu.mapapi.map.MapStatusUpdateFactory;
import com.baidu.mapapi.map.MapView;
import com.baidu.mapapi.model.LatLng;
import ohos.aafwk.content.Intent;
import ohos.agp.components.Button;
import ohos.agp.components.ComponentContainer;
import ohos.agp.window.dialog.ToastDialog;
import ohos.hiviewdfx.HiLog;

public class ShowMapAbility extends CustomAbility {
    int MAP_TYPE = BaiduMap.MAP_TYPE_NORMAL;

    /**
     * mapView
     */
    private MapView mMapView;

    /**
     * mapView控制器
     */
    private BaiduMap mBaiduMap;

    @Override
    public void onStart(Intent intent) {
        super.onStart(intent);
        setWindowBgToAdaptWebView();
        // 添加控件
        initPositionLayout();
        addMapView();
        addButtons();
        super.setUIContent(this.rootLayout);
    }

    @Override
    public void onActive() {
        super.onActive();
        mMapView.onResume();
    }

    @Override
    public void onForeground(Intent intent) {
        super.onForeground(intent);
        mMapView.onPause();
    }

    @Override
    protected void onStop() {
        super.onStop();
        mMapView.onDestroy();
    }

    private void addMapView() {
        // 创建mapView
        mMapView = new MapView(getContext());
        mMapView.setPosition(0, 0);
        mMapView.setWidth(ComponentContainer.LayoutConfig.MATCH_PARENT);
        mMapView.setHeight(ComponentContainer.LayoutConfig.MATCH_PARENT);
        this.rootLayout.addComponent(mMapView);
        mBaiduMap = mMapView.getMap();
        // 地图加载完成回调
        mBaiduMap.setOnMapLoadedCallback(() -> HiLog.debug(TAG, "onMapLoaded"));
        // 地图点击回调
        mBaiduMap.setOnMapClickListener(this::mapClicked);
        // 地图状态改变回调
        mBaiduMap.setOnMapStatusChangeListener(new BaiduMap.OnMapStatusChangeListener() {
            @Override
            public void onMapStatusChangeStart(MapStatus status) {
                mapStatusChangeStart(status);
            }

            @Override
            public void onMapStatusChange(MapStatus status) {
                mapStatusChange(status);
            }

            @Override
            public void onMapStatusChangeFinish(MapStatus status) {
                mapStatusChangeFinish(status);
            }
        });
    }

    private void addButtons() {
        // 添加一个按钮
        Button button = createButton();
        button.setContentPosition(0, vp2px(24));
        button.setText("changeMapType");
        button.setWidth(vp2px(130));

        button.setTouchEventListener((component, touchEvent) -> true);
        // btn 点击事件
        button.setClickedListener(component -> changeMapType());
        this.rootLayout.addComponent(button);

    }

    // 切换地图类型
    private void changeMapType() {
        HiLog.debug(TAG, "MAP_TYPE:" + MAP_TYPE);
//        mBaiduMap.getMapType(type -> HiLog.debug(TAG, "MAP_TYPE:" + type));

        if (MAP_TYPE == BaiduMap.MAP_TYPE_NORMAL) {
            mBaiduMap.setMapType(BaiduMap.MAP_TYPE_SATELLITE);
            MAP_TYPE = BaiduMap.MAP_TYPE_SATELLITE;
        } else {
            mBaiduMap.setMapType(BaiduMap.MAP_TYPE_NORMAL);
            MAP_TYPE = BaiduMap.MAP_TYPE_NORMAL;
        }
    }

    // 地图点击回调
    private void mapClicked(LatLng point) {
        new ToastDialog(getContext()).
                setText("onMapClick:" + point.toString()).
                show();
    }

    // 地图状态开始改变
    private void mapStatusChangeStart(MapStatus status) {
        HiLog.debug(TAG, "mapStatusChangeStart:" + status);
    }

    // 地图状态改变中
    private void mapStatusChange(MapStatus status) {
        HiLog.debug(TAG, "mapStatusChange:" + status);
    }

    // 地图状态改变完成
    private void mapStatusChangeFinish(MapStatus status) {
        HiLog.debug(TAG, "mapStatusChangeFinish:" + status);
    }

    // 设置地图中心点
    private void mapCenterAndZoom() {
        // 设置地图中心点
        MapStatus.Builder builder = new MapStatus.Builder();
        LatLng center = new LatLng(40.315, 116.404);
        builder.target(center).zoom(15);
//        builder.zoom(17);
        mBaiduMap.setMapStatus(MapStatusUpdateFactory.newMapStatus(builder.build()));

    }
}
